============
Cell classes
============

This document summarizes the classes denoted to store and handle data about polygonal cells
in 1, 2 or 3 dimensions.

.. automodule:: sigmaepsilon.mesh.cells
    :members: